@@ -12,38 +12,54 @@ def dynamic_import(abs_module_path, class_name):
 
 
 @click.group()
-@click.option('--c', "-config", help="Path of the config if different from standard",
-              default=None)
+@click.option(
+    "--c", "-config", help="Path of the config if different from standard", default=None
+)
 @click.pass_context
 def grimoire(ctx, c):
     ctx.obj = GrimoirePage(c)
 
 
 @grimoire.command(help="Run the command")
-@click.option('--c', "-command", help="Command to run. If not insert launch all the commands")
-@click.option('--u', "-url", help="On which url launch the command")
+@click.option("--c", "-command", help="Command to run. If not insert launch all the commands")
+@click.option("--u", "-url", help="On which url launch the command")
+@click.option('--stats/--no-stats', default=False, help="Launch stats after the run")
 @click.pass_context
-def run(ctx, c, u):
+def run(ctx, c, u, stats):
     ctx.obj.run(c, u)
+    if stats == True:
+        ctx.obj.stats(c, u)
 
 
 @grimoire.command(help="Show the stats")
-@click.option('--c', "-command", help="Stats to return. If not insert launch all the commands")
-@click.option('--u', "-url", help="On which url return the stats")
+@click.option(
+    "--c", "-command", help="Stats to return. If not insert launch all the commands"
+)
+@click.option("--u", "-url", help="On which url return the stats")
 @click.pass_context
 def stats(ctx, c, u):
     ctx.obj.stats(c, u)
 
 
-@grimoire.command(help="Add the url to the command check")
-@click.option('--u', "-url", help="Url to add", multiple=True)
+@grimoire.command(help="Show the info")
+@click.option("--u", "-url", help="On which url return the info")
+@click.option(
+    "--c", "-command", help="On which directive return the info"
+)
 @click.pass_context
-def add(ctx,  u):
-    ctx.obj.add( url= u)
+def info(ctx, c, u):
+    ctx.obj.info(command=c, url=u)
+
+
+@grimoire.command(help="Add the url to the command check")
+@click.option("--u", "-url", help="Url to add", multiple=True)
+@click.pass_context
+def add(ctx, u):
+    ctx.obj.add(url=u)
 
 
 @grimoire.command(help="Remove the url to the command check")
-@click.option('--u', "-url", help="Url to remove")
+@click.option("--u", "-url", help="Url to remove")
 @click.pass_context
 def remove(ctx, c, u):
     ctx.obj.remove(c, u)
@@ -51,7 +67,8 @@ def remove(ctx, c, u):
 
 @grimoire.command(help="Show the hello message")
 def hello():
-    print("""
+    print(
+        """
 .d8888b.                                                         
 d88P  Y88b                                                        
 Y88b.                                                             
@@ -71,4 +88,5 @@ d88P  Y88b         Y8P                        Y8P
 888    888 888     888 888  888  888 888  888 888 888    88888888 
 Y88b  d88P 888     888 888  888  888 Y88..88P 888 888    Y8b.     
  "Y8888P88 888     888 888  888  888  "Y88P"  888 888     "Y8888  
-    """)
+    """
+    )
